# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.injective.insurance.v1beta1 import genesis_pb2 as injective_dot_insurance_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/insurance/v1beta1/query.proto\x12\x1binjective.insurance.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a+injective/insurance/v1beta1/insurance.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a)injective/insurance/v1beta1/genesis.proto\"\x1d\n\x1bQueryInsuranceParamsRequest\"a\n\x1cQueryInsuranceParamsResponse\x12\x41\n\x06params\x18\x01 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"8\n\x19QueryInsuranceFundRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\\\n\x1aQueryInsuranceFundResponse\x12>\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundR\x04\x66und\"\x1c\n\x1aQueryInsuranceFundsRequest\"e\n\x1bQueryInsuranceFundsResponse\x12\x46\n\x05\x66unds\x18\x01 \x03(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundB\x04\xc8\xde\x1f\x00R\x05\x66unds\"X\n QueryEstimatedRedemptionsRequest\x12\x1a\n\x08marketId\x18\x01 \x01(\tR\x08marketId\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\\\n!QueryEstimatedRedemptionsResponse\x12\x37\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"V\n\x1eQueryPendingRedemptionsRequest\x12\x1a\n\x08marketId\x18\x01 \x01(\tR\x08marketId\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"Z\n\x1fQueryPendingRedemptionsResponse\x12\x37\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"\x19\n\x17QueryModuleStateRequest\"[\n\x18QueryModuleStateResponse\x12?\n\x05state\x18\x01 \x01(\x0b\x32).injective.insurance.v1beta1.GenesisStateR\x05state2\x96\t\n\x05Query\x12\xb3\x01\n\x0fInsuranceParams\x12\x38.injective.insurance.v1beta1.QueryInsuranceParamsRequest\x1a\x39.injective.insurance.v1beta1.QueryInsuranceParamsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/insurance/v1beta1/params\x12\xc1\x01\n\rInsuranceFund\x12\x36.injective.insurance.v1beta1.QueryInsuranceFundRequest\x1a\x37.injective.insurance.v1beta1.QueryInsuranceFundResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/insurance/v1beta1/insurance_fund/{market_id}\x12\xb9\x01\n\x0eInsuranceFunds\x12\x37.injective.insurance.v1beta1.QueryInsuranceFundsRequest\x1a\x38.injective.insurance.v1beta1.QueryInsuranceFundsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/insurance/v1beta1/insurance_funds\x12\xd1\x01\n\x14\x45stimatedRedemptions\x12=.injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest\x1a>.injective.insurance.v1beta1.QueryEstimatedRedemptionsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/insurance/v1beta1/estimated_redemptions\x12\xc9\x01\n\x12PendingRedemptions\x12;.injective.insurance.v1beta1.QueryPendingRedemptionsRequest\x1a<.injective.insurance.v1beta1.QueryPendingRedemptionsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/insurance/v1beta1/pending_redemptions\x12\xb6\x01\n\x14InsuranceModuleState\x12\x34.injective.insurance.v1beta1.QueryModuleStateRequest\x1a\x35.injective.insurance.v1beta1.QueryModuleStateResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/insurance/v1beta1/module_stateB\x8c\x02\n\x1f\x63om.injective.insurance.v1beta1B\nQueryProtoP\x01ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\xa2\x02\x03IIX\xaa\x02\x1bInjective.Insurance.V1beta1\xca\x02\x1bInjective\\Insurance\\V1beta1\xe2\x02\'Injective\\Insurance\\V1beta1\\GPBMetadata\xea\x02\x1dInjective::Insurance::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective.insurance.v1beta1B\nQueryProtoP\001ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\242\002\003IIX\252\002\033Injective.Insurance.V1beta1\312\002\033Injective\\Insurance\\V1beta1\342\002\'Injective\\Insurance\\V1beta1\\GPBMetadata\352\002\035Injective::Insurance::V1beta1'
  _globals['_QUERYINSURANCEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYINSURANCEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYINSURANCEFUNDSRESPONSE'].fields_by_name['funds']._loaded_options = None
  _globals['_QUERYINSURANCEFUNDSRESPONSE'].fields_by_name['funds']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYESTIMATEDREDEMPTIONSRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYESTIMATEDREDEMPTIONSRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPENDINGREDEMPTIONSRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYPENDINGREDEMPTIONSRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['InsuranceParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['InsuranceParams']._serialized_options = b'\202\323\344\223\002%\022#/injective/insurance/v1beta1/params'
  _globals['_QUERY'].methods_by_name['InsuranceFund']._loaded_options = None
  _globals['_QUERY'].methods_by_name['InsuranceFund']._serialized_options = b'\202\323\344\223\0029\0227/injective/insurance/v1beta1/insurance_fund/{market_id}'
  _globals['_QUERY'].methods_by_name['InsuranceFunds']._loaded_options = None
  _globals['_QUERY'].methods_by_name['InsuranceFunds']._serialized_options = b'\202\323\344\223\002.\022,/injective/insurance/v1beta1/insurance_funds'
  _globals['_QUERY'].methods_by_name['EstimatedRedemptions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EstimatedRedemptions']._serialized_options = b'\202\323\344\223\0024\0222/injective/insurance/v1beta1/estimated_redemptions'
  _globals['_QUERY'].methods_by_name['PendingRedemptions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PendingRedemptions']._serialized_options = b'\202\323\344\223\0022\0220/injective/insurance/v1beta1/pending_redemptions'
  _globals['_QUERY'].methods_by_name['InsuranceModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['InsuranceModuleState']._serialized_options = b'\202\323\344\223\002+\022)/injective/insurance/v1beta1/module_state'
  _globals['_QUERYINSURANCEPARAMSREQUEST']._serialized_start=244
  _globals['_QUERYINSURANCEPARAMSREQUEST']._serialized_end=273
  _globals['_QUERYINSURANCEPARAMSRESPONSE']._serialized_start=275
  _globals['_QUERYINSURANCEPARAMSRESPONSE']._serialized_end=372
  _globals['_QUERYINSURANCEFUNDREQUEST']._serialized_start=374
  _globals['_QUERYINSURANCEFUNDREQUEST']._serialized_end=430
  _globals['_QUERYINSURANCEFUNDRESPONSE']._serialized_start=432
  _globals['_QUERYINSURANCEFUNDRESPONSE']._serialized_end=524
  _globals['_QUERYINSURANCEFUNDSREQUEST']._serialized_start=526
  _globals['_QUERYINSURANCEFUNDSREQUEST']._serialized_end=554
  _globals['_QUERYINSURANCEFUNDSRESPONSE']._serialized_start=556
  _globals['_QUERYINSURANCEFUNDSRESPONSE']._serialized_end=657
  _globals['_QUERYESTIMATEDREDEMPTIONSREQUEST']._serialized_start=659
  _globals['_QUERYESTIMATEDREDEMPTIONSREQUEST']._serialized_end=747
  _globals['_QUERYESTIMATEDREDEMPTIONSRESPONSE']._serialized_start=749
  _globals['_QUERYESTIMATEDREDEMPTIONSRESPONSE']._serialized_end=841
  _globals['_QUERYPENDINGREDEMPTIONSREQUEST']._serialized_start=843
  _globals['_QUERYPENDINGREDEMPTIONSREQUEST']._serialized_end=929
  _globals['_QUERYPENDINGREDEMPTIONSRESPONSE']._serialized_start=931
  _globals['_QUERYPENDINGREDEMPTIONSRESPONSE']._serialized_end=1021
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=1023
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=1048
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=1050
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=1141
  _globals['_QUERY']._serialized_start=1144
  _globals['_QUERY']._serialized_end=2318
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/v1beta1/listening.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/store/v1beta1/listening.proto\x12\x14\x63osmos.store.v1beta1\x1a\x1c\x63ometbft/abci/v1/types.proto\"j\n\x0bStoreKVPair\x12\x1b\n\tstore_key\x18\x01 \x01(\tR\x08storeKey\x12\x16\n\x06\x64\x65lete\x18\x02 \x01(\x08R\x06\x64\x65lete\x12\x10\n\x03key\x18\x03 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x04 \x01(\x0cR\x05value\"\xb7\x02\n\rBlockMetadata\x12I\n\x0fresponse_commit\x18\x06 \x01(\x0b\x32 .cometbft.abci.v1.CommitResponseR\x0eresponseCommit\x12\\\n\x16request_finalize_block\x18\x07 \x01(\x0b\x32&.cometbft.abci.v1.FinalizeBlockRequestR\x14requestFinalizeBlock\x12_\n\x17response_finalize_block\x18\x08 \x01(\x0b\x32\'.cometbft.abci.v1.FinalizeBlockResponseR\x15responseFinalizeBlockJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\x42\xb6\x01\n\x18\x63om.cosmos.store.v1beta1B\x0eListeningProtoP\x01Z\x18\x63osmossdk.io/store/types\xa2\x02\x03\x43SX\xaa\x02\x14\x43osmos.Store.V1beta1\xca\x02\x14\x43osmos\\Store\\V1beta1\xe2\x02 Cosmos\\Store\\V1beta1\\GPBMetadata\xea\x02\x16\x43osmos::Store::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.v1beta1.listening_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.cosmos.store.v1beta1B\016ListeningProtoP\001Z\030cosmossdk.io/store/types\242\002\003CSX\252\002\024Cosmos.Store.V1beta1\312\002\024Cosmos\\Store\\V1beta1\342\002 Cosmos\\Store\\V1beta1\\GPBMetadata\352\002\026Cosmos::Store::V1beta1'
  _globals['_STOREKVPAIR']._serialized_start=92
  _globals['_STOREKVPAIR']._serialized_end=198
  _globals['_BLOCKMETADATA']._serialized_start=201
  _globals['_BLOCKMETADATA']._serialized_end=512
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/controller.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCibc/applications/interchain_accounts/controller/v1/controller.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\"7\n\x06Params\x12-\n\x12\x63ontroller_enabled\x18\x01 \x01(\x08R\x11\x63ontrollerEnabledB\x84\x03\n6com.ibc.applications.interchain_accounts.controller.v1B\x0f\x43ontrollerProtoP\x01ZPgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/controller/types\xa2\x02\x04IAIC\xaa\x02\x31Ibc.Applications.InterchainAccounts.Controller.V1\xca\x02\x31Ibc\\Applications\\InterchainAccounts\\Controller\\V1\xe2\x02=Ibc\\Applications\\InterchainAccounts\\Controller\\V1\\GPBMetadata\xea\x02\x35Ibc::Applications::InterchainAccounts::Controller::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.controller_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n6com.ibc.applications.interchain_accounts.controller.v1B\017ControllerProtoP\001ZPgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/controller/types\242\002\004IAIC\252\0021Ibc.Applications.InterchainAccounts.Controller.V1\312\0021Ibc\\Applications\\InterchainAccounts\\Controller\\V1\342\002=Ibc\\Applications\\InterchainAccounts\\Controller\\V1\\GPBMetadata\352\0025Ibc::Applications::InterchainAccounts::Controller::V1'
  _globals['_PARAMS']._serialized_start=123
  _globals['_PARAMS']._serialized_end=178
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/erc20/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.erc20.v1beta1 import params_pb2 as injective_dot_erc20_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.erc20.v1beta1 import erc20_pb2 as injective_dot_erc20_dot_v1beta1_dot_erc20__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/erc20/v1beta1/tx.proto\x12\x17injective.erc20.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a$injective/erc20/v1beta1/params.proto\x1a#injective/erc20/v1beta1/erc20.proto\x1a\x11\x61mino/amino.proto\"\xb2\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12=\n\x06params\x18\x02 \x01(\x0b\x32\x1f.injective.erc20.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:(\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x15\x65rc20/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xb2\x01\n\x12MsgCreateTokenPair\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12G\n\ntoken_pair\x18\x02 \x01(\x0b\x32\".injective.erc20.v1beta1.TokenPairB\x04\xc8\xde\x1f\x00R\ttokenPair:(\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x18\x65rc20/MsgCreateTokenPair\"e\n\x1aMsgCreateTokenPairResponse\x12G\n\ntoken_pair\x18\x01 \x01(\x0b\x32\".injective.erc20.v1beta1.TokenPairB\x04\xc8\xde\x1f\x00R\ttokenPair\"\x88\x01\n\x12MsgDeleteTokenPair\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12\x1d\n\nbank_denom\x18\x02 \x01(\tR\tbankDenom:(\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x18\x65rc20/MsgDeleteTokenPair\"\x1c\n\x1aMsgDeleteTokenPairResponse2\xe2\x02\n\x03Msg\x12j\n\x0cUpdateParams\x12(.injective.erc20.v1beta1.MsgUpdateParams\x1a\x30.injective.erc20.v1beta1.MsgUpdateParamsResponse\x12s\n\x0f\x43reateTokenPair\x12+.injective.erc20.v1beta1.MsgCreateTokenPair\x1a\x33.injective.erc20.v1beta1.MsgCreateTokenPairResponse\x12s\n\x0f\x44\x65leteTokenPair\x12+.injective.erc20.v1beta1.MsgDeleteTokenPair\x1a\x33.injective.erc20.v1beta1.MsgDeleteTokenPairResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xf1\x01\n\x1b\x63om.injective.erc20.v1beta1B\x07TxProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\xa2\x02\x03IEX\xaa\x02\x17Injective.Erc20.V1beta1\xca\x02\x17Injective\\Erc20\\V1beta1\xe2\x02#Injective\\Erc20\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Erc20::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.erc20.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.erc20.v1beta1B\007TxProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/erc20/types\242\002\003IEX\252\002\027Injective.Erc20.V1beta1\312\002\027Injective\\Erc20\\V1beta1\342\002#Injective\\Erc20\\V1beta1\\GPBMetadata\352\002\031Injective::Erc20::V1beta1'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\025erc20/MsgUpdateParams'
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['token_pair']._loaded_options = None
  _globals['_MSGCREATETOKENPAIR'].fields_by_name['token_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATETOKENPAIR']._loaded_options = None
  _globals['_MSGCREATETOKENPAIR']._serialized_options = b'\202\347\260*\006sender\212\347\260*\030erc20/MsgCreateTokenPair'
  _globals['_MSGCREATETOKENPAIRRESPONSE'].fields_by_name['token_pair']._loaded_options = None
  _globals['_MSGCREATETOKENPAIRRESPONSE'].fields_by_name['token_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MSGDELETETOKENPAIR'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGDELETETOKENPAIR'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGDELETETOKENPAIR']._loaded_options = None
  _globals['_MSGDELETETOKENPAIR']._serialized_options = b'\202\347\260*\006sender\212\347\260*\030erc20/MsgDeleteTokenPair'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=294
  _globals['_MSGUPDATEPARAMS']._serialized_end=472
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=474
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=499
  _globals['_MSGCREATETOKENPAIR']._serialized_start=502
  _globals['_MSGCREATETOKENPAIR']._serialized_end=680
  _globals['_MSGCREATETOKENPAIRRESPONSE']._serialized_start=682
  _globals['_MSGCREATETOKENPAIRRESPONSE']._serialized_end=783
  _globals['_MSGDELETETOKENPAIR']._serialized_start=786
  _globals['_MSGDELETETOKENPAIR']._serialized_end=922
  _globals['_MSGDELETETOKENPAIRRESPONSE']._serialized_start=924
  _globals['_MSGDELETETOKENPAIRRESPONSE']._serialized_end=952
  _globals['_MSG']._serialized_start=955
  _globals['_MSG']._serialized_end=1309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/abci/v1beta1/abci.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2
from pyinjective.proto.cometbft.types.v1 import block_pb2 as cometbft_dot_types_dot_v1_dot_block__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/base/abci/v1beta1/abci.proto\x12\x18\x63osmos.base.abci.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63ometbft/abci/v1/types.proto\x1a\x1d\x63ometbft/types/v1/block.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xcd\x03\n\nTxResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\"\n\x06txhash\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06TxHashR\x06txhash\x12\x1c\n\tcodespace\x18\x03 \x01(\tR\tcodespace\x12\x12\n\x04\x63ode\x18\x04 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x05 \x01(\tR\x04\x64\x61ta\x12\x17\n\x07raw_log\x18\x06 \x01(\tR\x06rawLog\x12U\n\x04logs\x18\x07 \x03(\x0b\x32(.cosmos.base.abci.v1beta1.ABCIMessageLogB\x17\xc8\xde\x1f\x00\xaa\xdf\x1f\x0f\x41\x42\x43IMessageLogsR\x04logs\x12\x12\n\x04info\x18\x08 \x01(\tR\x04info\x12\x1d\n\ngas_wanted\x18\t \x01(\x03R\tgasWanted\x12\x19\n\x08gas_used\x18\n \x01(\x03R\x07gasUsed\x12$\n\x02tx\x18\x0b \x01(\x0b\x32\x14.google.protobuf.AnyR\x02tx\x12\x1c\n\ttimestamp\x18\x0c \x01(\tR\ttimestamp\x12\x35\n\x06\x65vents\x18\r \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x04\xc8\xde\x1f\x00R\x06\x65vents:\x04\x88\xa0\x1f\x00\"\xa9\x01\n\x0e\x41\x42\x43IMessageLog\x12*\n\tmsg_index\x18\x01 \x01(\rB\r\xea\xde\x1f\tmsg_indexR\x08msgIndex\x12\x10\n\x03log\x18\x02 \x01(\tR\x03log\x12S\n\x06\x65vents\x18\x03 \x03(\x0b\x32%.cosmos.base.abci.v1beta1.StringEventB\x14\xc8\xde\x1f\x00\xaa\xdf\x1f\x0cStringEventsR\x06\x65vents:\x04\x80\xdc \x01\"r\n\x0bStringEvent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12I\n\nattributes\x18\x02 \x03(\x0b\x32#.cosmos.base.abci.v1beta1.AttributeB\x04\xc8\xde\x1f\x00R\nattributes:\x04\x80\xdc \x01\"3\n\tAttribute\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"C\n\x07GasInfo\x12\x1d\n\ngas_wanted\x18\x01 \x01(\x04R\tgasWanted\x12\x19\n\x08gas_used\x18\x02 \x01(\x04R\x07gasUsed\"\xaa\x01\n\x06Result\x12\x16\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x02\x18\x01R\x04\x64\x61ta\x12\x10\n\x03log\x18\x02 \x01(\tR\x03log\x12\x35\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x04\xc8\xde\x1f\x00R\x06\x65vents\x12\x39\n\rmsg_responses\x18\x04 \x03(\x0b\x32\x14.google.protobuf.AnyR\x0cmsgResponses:\x04\x88\xa0\x1f\x00\"\x96\x01\n\x12SimulationResponse\x12\x46\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfoB\x08\xc8\xde\x1f\x00\xd0\xde\x1f\x01R\x07gasInfo\x12\x38\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.ResultR\x06result\"@\n\x07MsgData\x12\x19\n\x08msg_type\x18\x01 \x01(\tR\x07msgType\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta:\x06\x18\x01\x80\xdc \x01\"\x87\x01\n\tTxMsgData\x12\x39\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32!.cosmos.base.abci.v1beta1.MsgDataB\x02\x18\x01R\x04\x64\x61ta\x12\x39\n\rmsg_responses\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyR\x0cmsgResponses:\x04\x80\xdc \x01\"\xdc\x01\n\x0fSearchTxsResult\x12\x1f\n\x0btotal_count\x18\x01 \x01(\x04R\ntotalCount\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount\x12\x1f\n\x0bpage_number\x18\x03 \x01(\x04R\npageNumber\x12\x1d\n\npage_total\x18\x04 \x01(\x04R\tpageTotal\x12\x14\n\x05limit\x18\x05 \x01(\x04R\x05limit\x12\x36\n\x03txs\x18\x06 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponseR\x03txs:\x04\x80\xdc \x01\"\xd9\x01\n\x12SearchBlocksResult\x12\x1f\n\x0btotal_count\x18\x01 \x01(\x03R\ntotalCount\x12\x14\n\x05\x63ount\x18\x02 \x01(\x03R\x05\x63ount\x12\x1f\n\x0bpage_number\x18\x03 \x01(\x03R\npageNumber\x12\x1d\n\npage_total\x18\x04 \x01(\x03R\tpageTotal\x12\x14\n\x05limit\x18\x05 \x01(\x03R\x05limit\x12\x30\n\x06\x62locks\x18\x06 \x03(\x0b\x32\x18.cometbft.types.v1.BlockR\x06\x62locks:\x04\x80\xdc \x01\x42\xd4\x01\n\x1c\x63om.cosmos.base.abci.v1beta1B\tAbciProtoP\x01Z\"github.com/cosmos/cosmos-sdk/types\xa2\x02\x03\x43\x42\x41\xaa\x02\x18\x43osmos.Base.Abci.V1beta1\xca\x02\x18\x43osmos\\Base\\Abci\\V1beta1\xe2\x02$Cosmos\\Base\\Abci\\V1beta1\\GPBMetadata\xea\x02\x1b\x43osmos::Base::Abci::V1beta1\xd8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.abci.v1beta1.abci_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cosmos.base.abci.v1beta1B\tAbciProtoP\001Z\"github.com/cosmos/cosmos-sdk/types\242\002\003CBA\252\002\030Cosmos.Base.Abci.V1beta1\312\002\030Cosmos\\Base\\Abci\\V1beta1\342\002$Cosmos\\Base\\Abci\\V1beta1\\GPBMetadata\352\002\033Cosmos::Base::Abci::V1beta1\330\341\036\000'
  _globals['_TXRESPONSE'].fields_by_name['txhash']._loaded_options = None
  _globals['_TXRESPONSE'].fields_by_name['txhash']._serialized_options = b'\342\336\037\006TxHash'
  _globals['_TXRESPONSE'].fields_by_name['logs']._loaded_options = None
  _globals['_TXRESPONSE'].fields_by_name['logs']._serialized_options = b'\310\336\037\000\252\337\037\017ABCIMessageLogs'
  _globals['_TXRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_TXRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _globals['_TXRESPONSE']._loaded_options = None
  _globals['_TXRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_ABCIMESSAGELOG'].fields_by_name['msg_index']._loaded_options = None
  _globals['_ABCIMESSAGELOG'].fields_by_name['msg_index']._serialized_options = b'\352\336\037\tmsg_index'
  _globals['_ABCIMESSAGELOG'].fields_by_name['events']._loaded_options = None
  _globals['_ABCIMESSAGELOG'].fields_by_name['events']._serialized_options = b'\310\336\037\000\252\337\037\014StringEvents'
  _globals['_ABCIMESSAGELOG']._loaded_options = None
  _globals['_ABCIMESSAGELOG']._serialized_options = b'\200\334 \001'
  _globals['_STRINGEVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_STRINGEVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000'
  _globals['_STRINGEVENT']._loaded_options = None
  _globals['_STRINGEVENT']._serialized_options = b'\200\334 \001'
  _globals['_RESULT'].fields_by_name['data']._loaded_options = None
  _globals['_RESULT'].fields_by_name['data']._serialized_options = b'\030\001'
  _globals['_RESULT'].fields_by_name['events']._loaded_options = None
  _globals['_RESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _globals['_RESULT']._loaded_options = None
  _globals['_RESULT']._serialized_options = b'\210\240\037\000'
  _globals['_SIMULATIONRESPONSE'].fields_by_name['gas_info']._loaded_options = None
  _globals['_SIMULATIONRESPONSE'].fields_by_name['gas_info']._serialized_options = b'\310\336\037\000\320\336\037\001'
  _globals['_MSGDATA']._loaded_options = None
  _globals['_MSGDATA']._serialized_options = b'\030\001\200\334 \001'
  _globals['_TXMSGDATA'].fields_by_name['data']._loaded_options = None
  _globals['_TXMSGDATA'].fields_by_name['data']._serialized_options = b'\030\001'
  _globals['_TXMSGDATA']._loaded_options = None
  _globals['_TXMSGDATA']._serialized_options = b'\200\334 \001'
  _globals['_SEARCHTXSRESULT']._loaded_options = None
  _globals['_SEARCHTXSRESULT']._serialized_options = b'\200\334 \001'
  _globals['_SEARCHBLOCKSRESULT']._loaded_options = None
  _globals['_SEARCHBLOCKSRESULT']._serialized_options = b'\200\334 \001'
  _globals['_TXRESPONSE']._serialized_start=203
  _globals['_TXRESPONSE']._serialized_end=664
  _globals['_ABCIMESSAGELOG']._serialized_start=667
  _globals['_ABCIMESSAGELOG']._serialized_end=836
  _globals['_STRINGEVENT']._serialized_start=838
  _globals['_STRINGEVENT']._serialized_end=952
  _globals['_ATTRIBUTE']._serialized_start=954
  _globals['_ATTRIBUTE']._serialized_end=1005
  _globals['_GASINFO']._serialized_start=1007
  _globals['_GASINFO']._serialized_end=1074
  _globals['_RESULT']._serialized_start=1077
  _globals['_RESULT']._serialized_end=1247
  _globals['_SIMULATIONRESPONSE']._serialized_start=1250
  _globals['_SIMULATIONRESPONSE']._serialized_end=1400
  _globals['_MSGDATA']._serialized_start=1402
  _globals['_MSGDATA']._serialized_end=1466
  _globals['_TXMSGDATA']._serialized_start=1469
  _globals['_TXMSGDATA']._serialized_end=1604
  _globals['_SEARCHTXSRESULT']._serialized_start=1607
  _globals['_SEARCHTXSRESULT']._serialized_end=1827
  _globals['_SEARCHBLOCKSRESULT']._serialized_start=1830
  _globals['_SEARCHBLOCKSRESULT']._serialized_end=2047
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/secp256k1/keys.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/crypto/secp256k1/keys.proto\x12\x17\x63osmos.crypto.secp256k1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\"M\n\x06PubKey\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key:1\x98\xa0\x1f\x00\x8a\xe7\xb0*\x1atendermint/PubKeySecp256k1\x92\xe7\xb0*\tkey_field\"K\n\x07PrivKey\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key:.\x8a\xe7\xb0*\x1btendermint/PrivKeySecp256k1\x92\xe7\xb0*\tkey_fieldB\xda\x01\n\x1b\x63om.cosmos.crypto.secp256k1B\tKeysProtoP\x01Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1\xa2\x02\x03\x43\x43S\xaa\x02\x17\x43osmos.Crypto.Secp256k1\xca\x02\x17\x43osmos\\Crypto\\Secp256k1\xe2\x02#Cosmos\\Crypto\\Secp256k1\\GPBMetadata\xea\x02\x19\x43osmos::Crypto::Secp256k1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.secp256k1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.cosmos.crypto.secp256k1B\tKeysProtoP\001Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1\242\002\003CCS\252\002\027Cosmos.Crypto.Secp256k1\312\002\027Cosmos\\Crypto\\Secp256k1\342\002#Cosmos\\Crypto\\Secp256k1\\GPBMetadata\352\002\031Cosmos::Crypto::Secp256k1'
  _globals['_PUBKEY']._loaded_options = None
  _globals['_PUBKEY']._serialized_options = b'\230\240\037\000\212\347\260*\032tendermint/PubKeySecp256k1\222\347\260*\tkey_field'
  _globals['_PRIVKEY']._loaded_options = None
  _globals['_PRIVKEY']._serialized_options = b'\212\347\260*\033tendermint/PrivKeySecp256k1\222\347\260*\tkey_field'
  _globals['_PUBKEY']._serialized_start=104
  _globals['_PUBKEY']._serialized_end=181
  _globals['_PRIVKEY']._serialized_start=183
  _globals['_PRIVKEY']._serialized_end=258
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.ibc.core.channel.v1 import tx_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the ibc/channel Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ChannelOpenInit = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenInit',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInit.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInitResponse.FromString,
                _registered_method=True)
        self.ChannelOpenTry = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenTry',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTry.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTryResponse.FromString,
                _registered_method=True)
        self.ChannelOpenAck = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenAck',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAck.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAckResponse.FromString,
                _registered_method=True)
        self.ChannelOpenConfirm = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenConfirm',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirm.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirmResponse.FromString,
                _registered_method=True)
        self.ChannelCloseInit = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelCloseInit',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInit.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInitResponse.FromString,
                _registered_method=True)
        self.ChannelCloseConfirm = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelCloseConfirm',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirm.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirmResponse.FromString,
                _registered_method=True)
        self.RecvPacket = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/RecvPacket',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacket.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacketResponse.FromString,
                _registered_method=True)
        self.Timeout = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/Timeout',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeout.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutResponse.FromString,
                _registered_method=True)
        self.TimeoutOnClose = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/TimeoutOnClose',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnClose.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnCloseResponse.FromString,
                _registered_method=True)
        self.Acknowledgement = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/Acknowledgement',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgement.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgementResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeInit = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeInit',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeInit.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeInitResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeTry = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeTry',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTry.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTryResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeAck = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeAck',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeAck.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeAckResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeConfirm = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeConfirm',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeConfirm.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeConfirmResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeOpen = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeOpen',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeOpen.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeOpenResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeTimeout = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeTimeout',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTimeout.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTimeoutResponse.FromString,
                _registered_method=True)
        self.ChannelUpgradeCancel = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelUpgradeCancel',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeCancel.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeCancelResponse.FromString,
                _registered_method=True)
        self.UpdateChannelParams = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/UpdateChannelParams',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.PruneAcknowledgements = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/PruneAcknowledgements',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgPruneAcknowledgements.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgPruneAcknowledgementsResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the ibc/channel Msg service.
    """

    def ChannelOpenInit(self, request, context):
        """ChannelOpenInit defines a rpc handler method for MsgChannelOpenInit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelOpenTry(self, request, context):
        """ChannelOpenTry defines a rpc handler method for MsgChannelOpenTry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelOpenAck(self, request, context):
        """ChannelOpenAck defines a rpc handler method for MsgChannelOpenAck.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelOpenConfirm(self, request, context):
        """ChannelOpenConfirm defines a rpc handler method for MsgChannelOpenConfirm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelCloseInit(self, request, context):
        """ChannelCloseInit defines a rpc handler method for MsgChannelCloseInit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelCloseConfirm(self, request, context):
        """ChannelCloseConfirm defines a rpc handler method for
        MsgChannelCloseConfirm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecvPacket(self, request, context):
        """RecvPacket defines a rpc handler method for MsgRecvPacket.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Timeout(self, request, context):
        """Timeout defines a rpc handler method for MsgTimeout.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TimeoutOnClose(self, request, context):
        """TimeoutOnClose defines a rpc handler method for MsgTimeoutOnClose.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Acknowledgement(self, request, context):
        """Acknowledgement defines a rpc handler method for MsgAcknowledgement.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeInit(self, request, context):
        """ChannelUpgradeInit defines a rpc handler method for MsgChannelUpgradeInit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeTry(self, request, context):
        """ChannelUpgradeTry defines a rpc handler method for MsgChannelUpgradeTry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeAck(self, request, context):
        """ChannelUpgradeAck defines a rpc handler method for MsgChannelUpgradeAck.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeConfirm(self, request, context):
        """ChannelUpgradeConfirm defines a rpc handler method for MsgChannelUpgradeConfirm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeOpen(self, request, context):
        """ChannelUpgradeOpen defines a rpc handler method for MsgChannelUpgradeOpen.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeTimeout(self, request, context):
        """ChannelUpgradeTimeout defines a rpc handler method for MsgChannelUpgradeTimeout.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelUpgradeCancel(self, request, context):
        """ChannelUpgradeCancel defines a rpc handler method for MsgChannelUpgradeCancel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateChannelParams(self, request, context):
        """UpdateChannelParams defines a rpc handler method for MsgUpdateParams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PruneAcknowledgements(self, request, context):
        """PruneAcknowledgements defines a rpc handler method for MsgPruneAcknowledgements.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ChannelOpenInit': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenInit,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInit.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInitResponse.SerializeToString,
            ),
            'ChannelOpenTry': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenTry,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTry.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTryResponse.SerializeToString,
            ),
            'ChannelOpenAck': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenAck,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAck.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAckResponse.SerializeToString,
            ),
            'ChannelOpenConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenConfirm,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirm.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirmResponse.SerializeToString,
            ),
            'ChannelCloseInit': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelCloseInit,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInit.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInitResponse.SerializeToString,
            ),
            'ChannelCloseConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelCloseConfirm,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirm.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirmResponse.SerializeToString,
            ),
            'RecvPacket': grpc.unary_unary_rpc_method_handler(
                    servicer.RecvPacket,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacket.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacketResponse.SerializeToString,
            ),
            'Timeout': grpc.unary_unary_rpc_method_handler(
                    servicer.Timeout,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeout.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutResponse.SerializeToString,
            ),
            'TimeoutOnClose': grpc.unary_unary_rpc_method_handler(
                    servicer.TimeoutOnClose,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnClose.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnCloseResponse.SerializeToString,
            ),
            'Acknowledgement': grpc.unary_unary_rpc_method_handler(
                    servicer.Acknowledgement,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgement.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgementResponse.SerializeToString,
            ),
            'ChannelUpgradeInit': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeInit,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeInit.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeInitResponse.SerializeToString,
            ),
            'ChannelUpgradeTry': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeTry,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTry.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTryResponse.SerializeToString,
            ),
            'ChannelUpgradeAck': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeAck,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeAck.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeAckResponse.SerializeToString,
            ),
            'ChannelUpgradeConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeConfirm,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeConfirm.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeConfirmResponse.SerializeToString,
            ),
            'ChannelUpgradeOpen': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeOpen,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeOpen.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeOpenResponse.SerializeToString,
            ),
            'ChannelUpgradeTimeout': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeTimeout,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTimeout.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTimeoutResponse.SerializeToString,
            ),
            'ChannelUpgradeCancel': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelUpgradeCancel,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeCancel.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeCancelResponse.SerializeToString,
            ),
            'UpdateChannelParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateChannelParams,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'PruneAcknowledgements': grpc.unary_unary_rpc_method_handler(
                    servicer.PruneAcknowledgements,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgPruneAcknowledgements.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgPruneAcknowledgementsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.core.channel.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ibc.core.channel.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the ibc/channel Msg service.
    """

    @staticmethod
    def ChannelOpenInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelOpenInit',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInit.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelOpenTry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelOpenTry',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTry.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelOpenAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelOpenAck',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAck.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelOpenConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelOpenConfirm',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirm.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelCloseInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelCloseInit',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInit.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelCloseConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelCloseConfirm',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirm.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RecvPacket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/RecvPacket',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacket.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacketResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Timeout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/Timeout',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeout.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TimeoutOnClose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/TimeoutOnClose',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnClose.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnCloseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Acknowledgement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/Acknowledgement',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgement.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeInit',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeInit.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeInitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeTry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeTry',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTry.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeAck',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeAck.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeAckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeConfirm',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeConfirm.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeConfirmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeOpen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeOpen',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeOpen.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeOpenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeTimeout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeTimeout',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTimeout.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeTimeoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ChannelUpgradeCancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/ChannelUpgradeCancel',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeCancel.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelUpgradeCancelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateChannelParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/UpdateChannelParams',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PruneAcknowledgements(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ibc.core.channel.v1.Msg/PruneAcknowledgements',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgPruneAcknowledgements.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgPruneAcknowledgementsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_campaign_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_campaign_rpc.proto\x12\x16injective_campaign_rpc\"\xcc\x01\n\x0eRankingRequest\x12\x1f\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\tR\ncampaignId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x14\n\x05limit\x18\x04 \x01(\x11R\x05limit\x12\x12\n\x04skip\x18\x05 \x01(\x04R\x04skip\x12)\n\x10\x63ontract_address\x18\x06 \x01(\tR\x0f\x63ontractAddress\"\xc3\x01\n\x0fRankingResponse\x12<\n\x08\x63\x61mpaign\x18\x01 \x01(\x0b\x32 .injective_campaign_rpc.CampaignR\x08\x63\x61mpaign\x12:\n\x05users\x18\x02 \x03(\x0b\x32$.injective_campaign_rpc.CampaignUserR\x05users\x12\x36\n\x06paging\x18\x03 \x01(\x0b\x32\x1e.injective_campaign_rpc.PagingR\x06paging\"\xb2\x04\n\x08\x43\x61mpaign\x12\x1f\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\tR\ncampaignId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1f\n\x0btotal_score\x18\x04 \x01(\tR\ntotalScore\x12!\n\x0clast_updated\x18\x05 \x01(\x12R\x0blastUpdated\x12\x1d\n\nstart_date\x18\x06 \x01(\x12R\tstartDate\x12\x19\n\x08\x65nd_date\x18\x07 \x01(\x12R\x07\x65ndDate\x12!\n\x0cis_claimable\x18\x08 \x01(\x08R\x0bisClaimable\x12\x19\n\x08round_id\x18\t \x01(\x11R\x07roundId\x12)\n\x10manager_contract\x18\n \x01(\tR\x0fmanagerContract\x12\x36\n\x07rewards\x18\x0b \x03(\x0b\x32\x1c.injective_campaign_rpc.CoinR\x07rewards\x12\x1d\n\nuser_score\x18\x0c \x01(\tR\tuserScore\x12!\n\x0cuser_claimed\x18\r \x01(\x08R\x0buserClaimed\x12\x30\n\x14subaccount_id_suffix\x18\x0e \x01(\tR\x12subaccountIdSuffix\x12\'\n\x0freward_contract\x18\x0f \x01(\tR\x0erewardContract\x12\x18\n\x07version\x18\x10 \x01(\tR\x07version\x12\x12\n\x04type\x18\x11 \x01(\tR\x04type\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"\xef\x02\n\x0c\x43\x61mpaignUser\x12\x1f\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\tR\ncampaignId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x14\n\x05score\x18\x04 \x01(\tR\x05score\x12)\n\x10\x63ontract_updated\x18\x05 \x01(\x08R\x0f\x63ontractUpdated\x12!\n\x0c\x62lock_height\x18\x06 \x01(\x12R\x0b\x62lockHeight\x12\x1d\n\nblock_time\x18\x07 \x01(\x12R\tblockTime\x12)\n\x10purchased_amount\x18\x08 \x01(\tR\x0fpurchasedAmount\x12#\n\rgalxe_updated\x18\t \x01(\x08R\x0cgalxeUpdated\x12%\n\x0ereward_claimed\x18\n \x01(\x08R\rrewardClaimed\"\x86\x01\n\x06Paging\x12\x14\n\x05total\x18\x01 \x01(\x12R\x05total\x12\x12\n\x04\x66rom\x18\x02 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x03 \x01(\x11R\x02to\x12.\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12R\x11\x63ountBySubaccount\x12\x12\n\x04next\x18\x05 \x03(\tR\x04next\"\xb5\x01\n\x10\x43\x61mpaignsRequest\x12\x19\n\x08round_id\x18\x01 \x01(\x12R\x07roundId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x1e\n\x0bto_round_id\x18\x03 \x01(\x11R\ttoRoundId\x12)\n\x10\x63ontract_address\x18\x04 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04type\x18\x05 \x01(\tR\x04type\"\xc5\x01\n\x11\x43\x61mpaignsResponse\x12>\n\tcampaigns\x18\x01 \x03(\x0b\x32 .injective_campaign_rpc.CampaignR\tcampaigns\x12M\n\x13\x61\x63\x63umulated_rewards\x18\x02 \x03(\x0b\x32\x1c.injective_campaign_rpc.CoinR\x12\x61\x63\x63umulatedRewards\x12!\n\x0creward_count\x18\x03 \x01(\x11R\x0brewardCount\"\x96\x02\n\x12\x43\x61mpaignsV2Request\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x02 \x01(\x08R\x06\x61\x63tive\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\x12\x16\n\x06\x63ursor\x18\x04 \x01(\tR\x06\x63ursor\x12&\n\x0f\x66rom_start_date\x18\x05 \x01(\x12R\rfromStartDate\x12\"\n\rto_start_date\x18\x06 \x01(\x12R\x0btoStartDate\x12\"\n\rfrom_end_date\x18\x07 \x01(\x12R\x0b\x66romEndDate\x12\x1e\n\x0bto_end_date\x18\x08 \x01(\x12R\ttoEndDate\x12\x16\n\x06status\x18\t \x01(\tR\x06status\"o\n\x13\x43\x61mpaignsV2Response\x12@\n\tcampaigns\x18\x01 \x03(\x0b\x32\".injective_campaign_rpc.CampaignV2R\tcampaigns\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\"\xc3\x04\n\nCampaignV2\x12\x1f\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\tR\ncampaignId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1f\n\x0btotal_score\x18\x04 \x01(\tR\ntotalScore\x12\x1d\n\ncreated_at\x18\x05 \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x1d\n\nstart_date\x18\x07 \x01(\x12R\tstartDate\x12\x19\n\x08\x65nd_date\x18\x08 \x01(\x12R\x07\x65ndDate\x12!\n\x0cis_claimable\x18\t \x01(\x08R\x0bisClaimable\x12\x19\n\x08round_id\x18\n \x01(\x11R\x07roundId\x12)\n\x10manager_contract\x18\x0b \x01(\tR\x0fmanagerContract\x12\x36\n\x07rewards\x18\x0c \x03(\x0b\x32\x1c.injective_campaign_rpc.CoinR\x07rewards\x12\x30\n\x14subaccount_id_suffix\x18\r \x01(\tR\x12subaccountIdSuffix\x12\'\n\x0freward_contract\x18\x0e \x01(\tR\x0erewardContract\x12\x12\n\x04type\x18\x0f \x01(\tR\x04type\x12\x18\n\x07version\x18\x10 \x01(\tR\x07version\x12\x12\n\x04name\x18\x11 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x12 \x01(\tR\x0b\x64\x65scription\"\x83\x01\n\x11ListGuildsRequest\x12+\n\x11\x63\x61mpaign_contract\x18\x01 \x01(\tR\x10\x63\x61mpaignContract\x12\x14\n\x05limit\x18\x02 \x01(\x11R\x05limit\x12\x12\n\x04skip\x18\x03 \x01(\x11R\x04skip\x12\x17\n\x07sort_by\x18\x04 \x01(\tR\x06sortBy\"\xf6\x01\n\x12ListGuildsResponse\x12\x35\n\x06guilds\x18\x01 \x03(\x0b\x32\x1d.injective_campaign_rpc.GuildR\x06guilds\x12\x36\n\x06paging\x18\x02 \x01(\x0b\x32\x1e.injective_campaign_rpc.PagingR\x06paging\x12\x1d\n\nupdated_at\x18\x03 \x01(\x12R\tupdatedAt\x12R\n\x10\x63\x61mpaign_summary\x18\x04 \x01(\x0b\x32\'.injective_campaign_rpc.CampaignSummaryR\x0f\x63\x61mpaignSummary\"\xe5\x03\n\x05Guild\x12+\n\x11\x63\x61mpaign_contract\x18\x01 \x01(\tR\x10\x63\x61mpaignContract\x12\x19\n\x08guild_id\x18\x02 \x01(\tR\x07guildId\x12%\n\x0emaster_address\x18\x03 \x01(\tR\rmasterAddress\x12\x1d\n\ncreated_at\x18\x04 \x01(\x12R\tcreatedAt\x12\x1b\n\ttvl_score\x18\x05 \x01(\tR\x08tvlScore\x12!\n\x0cvolume_score\x18\x06 \x01(\tR\x0bvolumeScore\x12$\n\x0erank_by_volume\x18\x07 \x01(\x11R\x0crankByVolume\x12\x1e\n\x0brank_by_tvl\x18\x08 \x01(\x11R\trankByTvl\x12\x12\n\x04logo\x18\t \x01(\tR\x04logo\x12\x1b\n\ttotal_tvl\x18\n \x01(\tR\x08totalTvl\x12\x1d\n\nupdated_at\x18\x0b \x01(\x12R\tupdatedAt\x12\x12\n\x04name\x18\x0e \x01(\tR\x04name\x12\x1b\n\tis_active\x18\r \x01(\x08R\x08isActive\x12%\n\x0emaster_balance\x18\x0f \x01(\tR\rmasterBalance\x12 \n\x0b\x64\x65scription\x18\x10 \x01(\tR\x0b\x64\x65scription\"\x82\x03\n\x0f\x43\x61mpaignSummary\x12\x1f\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\tR\ncampaignId\x12+\n\x11\x63\x61mpaign_contract\x18\x02 \x01(\tR\x10\x63\x61mpaignContract\x12,\n\x12total_guilds_count\x18\x03 \x01(\x11R\x10totalGuildsCount\x12\x1b\n\ttotal_tvl\x18\x04 \x01(\tR\x08totalTvl\x12*\n\x11total_average_tvl\x18\x05 \x01(\tR\x0ftotalAverageTvl\x12!\n\x0ctotal_volume\x18\x06 \x01(\tR\x0btotalVolume\x12\x1d\n\nupdated_at\x18\x07 \x01(\x12R\tupdatedAt\x12.\n\x13total_members_count\x18\x08 \x01(\x11R\x11totalMembersCount\x12\x1d\n\nstart_time\x18\t \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\n \x01(\x12R\x07\x65ndTime\"\xd2\x01\n\x17ListGuildMembersRequest\x12+\n\x11\x63\x61mpaign_contract\x18\x01 \x01(\tR\x10\x63\x61mpaignContract\x12\x19\n\x08guild_id\x18\x02 \x01(\tR\x07guildId\x12\x14\n\x05limit\x18\x03 \x01(\x11R\x05limit\x12\x12\n\x04skip\x18\x04 \x01(\x11R\x04skip\x12,\n\x12include_guild_info\x18\x05 \x01(\x08R\x10includeGuildInfo\x12\x17\n\x07sort_by\x18\x06 \x01(\tR\x06sortBy\"\xcf\x01\n\x18ListGuildMembersResponse\x12=\n\x07members\x18\x01 \x03(\x0b\x32#.injective_campaign_rpc.GuildMemberR\x07members\x12\x36\n\x06paging\x18\x02 \x01(\x0b\x32\x1e.injective_campaign_rpc.PagingR\x06paging\x12<\n\nguild_info\x18\x03 \x01(\x0b\x32\x1d.injective_campaign_rpc.GuildR\tguildInfo\"\xd3\x03\n\x0bGuildMember\x12+\n\x11\x63\x61mpaign_contract\x18\x01 \x01(\tR\x10\x63\x61mpaignContract\x12\x19\n\x08guild_id\x18\x02 \x01(\tR\x07guildId\x12\x18\n\x07\x61\x64\x64ress\x18\x03 \x01(\tR\x07\x61\x64\x64ress\x12\x1b\n\tjoined_at\x18\x04 \x01(\x12R\x08joinedAt\x12\x1b\n\ttvl_score\x18\x05 \x01(\tR\x08tvlScore\x12!\n\x0cvolume_score\x18\x06 \x01(\tR\x0bvolumeScore\x12\x1b\n\ttotal_tvl\x18\x07 \x01(\tR\x08totalTvl\x12\x36\n\x17volume_score_percentage\x18\x08 \x01(\x01R\x15volumeScorePercentage\x12\x30\n\x14tvl_score_percentage\x18\t \x01(\x01R\x12tvlScorePercentage\x12;\n\ntvl_reward\x18\n \x03(\x0b\x32\x1c.injective_campaign_rpc.CoinR\ttvlReward\x12\x41\n\rvolume_reward\x18\x0b \x03(\x0b\x32\x1c.injective_campaign_rpc.CoinR\x0cvolumeReward\"^\n\x15GetGuildMemberRequest\x12+\n\x11\x63\x61mpaign_contract\x18\x01 \x01(\tR\x10\x63\x61mpaignContract\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"Q\n\x16GetGuildMemberResponse\x12\x37\n\x04info\x18\x01 \x01(\x0b\x32#.injective_campaign_rpc.GuildMemberR\x04info2\x89\x05\n\x14InjectiveCampaignRPC\x12Z\n\x07Ranking\x12&.injective_campaign_rpc.RankingRequest\x1a\'.injective_campaign_rpc.RankingResponse\x12`\n\tCampaigns\x12(.injective_campaign_rpc.CampaignsRequest\x1a).injective_campaign_rpc.CampaignsResponse\x12\x66\n\x0b\x43\x61mpaignsV2\x12*.injective_campaign_rpc.CampaignsV2Request\x1a+.injective_campaign_rpc.CampaignsV2Response\x12\x63\n\nListGuilds\x12).injective_campaign_rpc.ListGuildsRequest\x1a*.injective_campaign_rpc.ListGuildsResponse\x12u\n\x10ListGuildMembers\x12/.injective_campaign_rpc.ListGuildMembersRequest\x1a\x30.injective_campaign_rpc.ListGuildMembersResponse\x12o\n\x0eGetGuildMember\x12-.injective_campaign_rpc.GetGuildMemberRequest\x1a..injective_campaign_rpc.GetGuildMemberResponseB\xc2\x01\n\x1a\x63om.injective_campaign_rpcB\x19InjectiveCampaignRpcProtoP\x01Z\x19/injective_campaign_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveCampaignRpc\xca\x02\x14InjectiveCampaignRpc\xe2\x02 InjectiveCampaignRpc\\GPBMetadata\xea\x02\x14InjectiveCampaignRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_campaign_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_campaign_rpcB\031InjectiveCampaignRpcProtoP\001Z\031/injective_campaign_rpcpb\242\002\003IXX\252\002\024InjectiveCampaignRpc\312\002\024InjectiveCampaignRpc\342\002 InjectiveCampaignRpc\\GPBMetadata\352\002\024InjectiveCampaignRpc'
  _globals['_RANKINGREQUEST']._serialized_start=66
  _globals['_RANKINGREQUEST']._serialized_end=270
  _globals['_RANKINGRESPONSE']._serialized_start=273
  _globals['_RANKINGRESPONSE']._serialized_end=468
  _globals['_CAMPAIGN']._serialized_start=471
  _globals['_CAMPAIGN']._serialized_end=1033
  _globals['_COIN']._serialized_start=1035
  _globals['_COIN']._serialized_end=1116
  _globals['_CAMPAIGNUSER']._serialized_start=1119
  _globals['_CAMPAIGNUSER']._serialized_end=1486
  _globals['_PAGING']._serialized_start=1489
  _globals['_PAGING']._serialized_end=1623
  _globals['_CAMPAIGNSREQUEST']._serialized_start=1626
  _globals['_CAMPAIGNSREQUEST']._serialized_end=1807
  _globals['_CAMPAIGNSRESPONSE']._serialized_start=1810
  _globals['_CAMPAIGNSRESPONSE']._serialized_end=2007
  _globals['_CAMPAIGNSV2REQUEST']._serialized_start=2010
  _globals['_CAMPAIGNSV2REQUEST']._serialized_end=2288
  _globals['_CAMPAIGNSV2RESPONSE']._serialized_start=2290
  _globals['_CAMPAIGNSV2RESPONSE']._serialized_end=2401
  _globals['_CAMPAIGNV2']._serialized_start=2404
  _globals['_CAMPAIGNV2']._serialized_end=2983
  _globals['_LISTGUILDSREQUEST']._serialized_start=2986
  _globals['_LISTGUILDSREQUEST']._serialized_end=3117
  _globals['_LISTGUILDSRESPONSE']._serialized_start=3120
  _globals['_LISTGUILDSRESPONSE']._serialized_end=3366
  _globals['_GUILD']._serialized_start=3369
  _globals['_GUILD']._serialized_end=3854
  _globals['_CAMPAIGNSUMMARY']._serialized_start=3857
  _globals['_CAMPAIGNSUMMARY']._serialized_end=4243
  _globals['_LISTGUILDMEMBERSREQUEST']._serialized_start=4246
  _globals['_LISTGUILDMEMBERSREQUEST']._serialized_end=4456
  _globals['_LISTGUILDMEMBERSRESPONSE']._serialized_start=4459
  _globals['_LISTGUILDMEMBERSRESPONSE']._serialized_end=4666
  _globals['_GUILDMEMBER']._serialized_start=4669
  _globals['_GUILDMEMBER']._serialized_end=5136
  _globals['_GETGUILDMEMBERREQUEST']._serialized_start=5138
  _globals['_GETGUILDMEMBERREQUEST']._serialized_end=5232
  _globals['_GETGUILDMEMBERRESPONSE']._serialized_start=5234
  _globals['_GETGUILDMEMBERRESPONSE']._serialized_end=5315
  _globals['_INJECTIVECAMPAIGNRPC']._serialized_start=5318
  _globals['_INJECTIVECAMPAIGNRPC']._serialized_end=5967
# @@protoc_insertion_point(module_scope)



from pyinjective.proto.cosmos.auth.v1beta1 import query_pb2 as auth_query_pb


class AuthParams:
    def __init__(
        self,
        max_memo_characters: int,
        tx_sig_limit: int,
        tx_size_cost_per_byte: int,
        sig_verify_cost_ed25519: int,
        sig_verify_cost_secp256k1: int,
    ):
        super().__init__()
        self.max_memo_characters = max_memo_characters
        self.tx_sig_limit = tx_sig_limit
        self.tx_size_cost_per_byte = tx_size_cost_per_byte
        self.sig_verify_cost_ed25519 = sig_verify_cost_ed25519
        self.sig_verify_cost_secp256k1 = sig_verify_cost_secp256k1

    @classmethod
    def from_proto_response(cls, response: auth_query_pb.QueryParamsResponse):
        return cls(
            max_memo_characters=response.params.max_memo_characters,
            tx_sig_limit=response.params.tx_sig_limit,
            tx_size_cost_per_byte=response.params.tx_size_cost_per_byte,
            sig_verify_cost_ed25519=response.params.sig_verify_cost_ed25519,
            sig_verify_cost_secp256k1=response.params.sig_verify_cost_secp256k1,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/orm/v1alpha1/schema.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/orm/v1alpha1/schema.proto\x12\x13\x63osmos.orm.v1alpha1\x1a google/protobuf/descriptor.proto\"\x93\x02\n\x16ModuleSchemaDescriptor\x12V\n\x0bschema_file\x18\x01 \x03(\x0b\x32\x35.cosmos.orm.v1alpha1.ModuleSchemaDescriptor.FileEntryR\nschemaFile\x12\x16\n\x06prefix\x18\x02 \x01(\x0cR\x06prefix\x1a\x88\x01\n\tFileEntry\x12\x0e\n\x02id\x18\x01 \x01(\rR\x02id\x12&\n\x0fproto_file_name\x18\x02 \x01(\tR\rprotoFileName\x12\x43\n\x0cstorage_type\x18\x03 \x01(\x0e\x32 .cosmos.orm.v1alpha1.StorageTypeR\x0bstorageType*h\n\x0bStorageType\x12$\n STORAGE_TYPE_DEFAULT_UNSPECIFIED\x10\x00\x12\x17\n\x13STORAGE_TYPE_MEMORY\x10\x01\x12\x1a\n\x16STORAGE_TYPE_TRANSIENT\x10\x02:t\n\rmodule_schema\x12\x1f.google.protobuf.MessageOptions\x18\xf0\xb3\xea\x31 \x01(\x0b\x32+.cosmos.orm.v1alpha1.ModuleSchemaDescriptorR\x0cmoduleSchemaB\x94\x01\n\x17\x63om.cosmos.orm.v1alpha1B\x0bSchemaProtoP\x01\xa2\x02\x03\x43OX\xaa\x02\x13\x43osmos.Orm.V1alpha1\xca\x02\x13\x43osmos\\Orm\\V1alpha1\xe2\x02\x1f\x43osmos\\Orm\\V1alpha1\\GPBMetadata\xea\x02\x15\x43osmos::Orm::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.orm.v1alpha1.schema_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.orm.v1alpha1B\013SchemaProtoP\001\242\002\003COX\252\002\023Cosmos.Orm.V1alpha1\312\002\023Cosmos\\Orm\\V1alpha1\342\002\037Cosmos\\Orm\\V1alpha1\\GPBMetadata\352\002\025Cosmos::Orm::V1alpha1'
  _globals['_STORAGETYPE']._serialized_start=369
  _globals['_STORAGETYPE']._serialized_end=473
  _globals['_MODULESCHEMADESCRIPTOR']._serialized_start=92
  _globals['_MODULESCHEMADESCRIPTOR']._serialized_end=367
  _globals['_MODULESCHEMADESCRIPTOR_FILEENTRY']._serialized_start=231
  _globals['_MODULESCHEMADESCRIPTOR_FILEENTRY']._serialized_end=367
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.ibc.core.client.v1 import query_pb2 as ibc_client_query, query_pb2_grpc as ibc_client_query_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IBCClientGrpcApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = ibc_client_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_client_state(self, client_id: str) -> Dict[str, Any]:
        request = ibc_client_query.QueryClientStateRequest(client_id=client_id)
        response = await self._execute_call(call=self._stub.ClientState, request=request)

        return response

    async def fetch_client_states(self, pagination: Optional[PaginationOption] = None) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_client_query.QueryClientStatesRequest(pagination=pagination.create_pagination_request())
        response = await self._execute_call(call=self._stub.ClientStates, request=request)

        return response

    async def fetch_consensus_state(
        self,
        client_id: str,
        revision_number: int,
        revision_height: int,
        latest_height: Optional[bool] = None,
    ) -> Dict[str, Any]:
        request = ibc_client_query.QueryConsensusStateRequest(
            client_id=client_id,
            revision_number=revision_number,
            revision_height=revision_height,
            latest_height=latest_height,
        )
        response = await self._execute_call(call=self._stub.ConsensusState, request=request)

        return response

    async def fetch_consensus_states(
        self, client_id: str, pagination: Optional[PaginationOption] = None
    ) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_client_query.QueryConsensusStatesRequest(
            client_id=client_id, pagination=pagination.create_pagination_request()
        )
        response = await self._execute_call(call=self._stub.ConsensusStates, request=request)

        return response

    async def fetch_consensus_state_heights(
        self, client_id: str, pagination: Optional[PaginationOption] = None
    ) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = ibc_client_query.QueryConsensusStateHeightsRequest(
            client_id=client_id, pagination=pagination.create_pagination_request()
        )
        response = await self._execute_call(call=self._stub.ConsensusStateHeights, request=request)

        return response

    async def fetch_client_status(self, client_id: str) -> Dict[str, Any]:
        request = ibc_client_query.QueryClientStatusRequest(client_id=client_id)
        response = await self._execute_call(call=self._stub.ClientStatus, request=request)

        return response

    async def fetch_client_params(self) -> Dict[str, Any]:
        request = ibc_client_query.QueryClientParamsRequest()
        response = await self._execute_call(call=self._stub.ClientParams, request=request)

        return response

    async def fetch_upgraded_client_state(self) -> Dict[str, Any]:
        request = ibc_client_query.QueryUpgradedClientStateRequest()
        response = await self._execute_call(call=self._stub.UpgradedClientState, request=request)

        return response

    async def fetch_upgraded_consensus_state(self) -> Dict[str, Any]:
        request = ibc_client_query.QueryUpgradedConsensusStateRequest()
        response = await self._execute_call(call=self._stub.UpgradedConsensusState, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/stream/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.exchange.v1beta1 import events_pb2 as injective_dot_exchange_dot_v1beta1_dot_events__pb2
from pyinjective.proto.injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/stream/v1beta1/query.proto\x12\x18injective.stream.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\'injective/exchange/v1beta1/events.proto\x1a)injective/exchange/v1beta1/exchange.proto\"\x8e\x08\n\rStreamRequest\x12\x64\n\x14\x62\x61nk_balances_filter\x18\x01 \x01(\x0b\x32,.injective.stream.v1beta1.BankBalancesFilterB\x04\xc8\xde\x1f\x01R\x12\x62\x61nkBalancesFilter\x12v\n\x1asubaccount_deposits_filter\x18\x02 \x01(\x0b\x32\x32.injective.stream.v1beta1.SubaccountDepositsFilterB\x04\xc8\xde\x1f\x01R\x18subaccountDepositsFilter\x12Z\n\x12spot_trades_filter\x18\x03 \x01(\x0b\x32&.injective.stream.v1beta1.TradesFilterB\x04\xc8\xde\x1f\x01R\x10spotTradesFilter\x12\x66\n\x18\x64\x65rivative_trades_filter\x18\x04 \x01(\x0b\x32&.injective.stream.v1beta1.TradesFilterB\x04\xc8\xde\x1f\x01R\x16\x64\x65rivativeTradesFilter\x12Z\n\x12spot_orders_filter\x18\x05 \x01(\x0b\x32&.injective.stream.v1beta1.OrdersFilterB\x04\xc8\xde\x1f\x01R\x10spotOrdersFilter\x12\x66\n\x18\x64\x65rivative_orders_filter\x18\x06 \x01(\x0b\x32&.injective.stream.v1beta1.OrdersFilterB\x04\xc8\xde\x1f\x01R\x16\x64\x65rivativeOrdersFilter\x12\x65\n\x16spot_orderbooks_filter\x18\x07 \x01(\x0b\x32).injective.stream.v1beta1.OrderbookFilterB\x04\xc8\xde\x1f\x01R\x14spotOrderbooksFilter\x12q\n\x1c\x64\x65rivative_orderbooks_filter\x18\x08 \x01(\x0b\x32).injective.stream.v1beta1.OrderbookFilterB\x04\xc8\xde\x1f\x01R\x1a\x64\x65rivativeOrderbooksFilter\x12Z\n\x10positions_filter\x18\t \x01(\x0b\x32).injective.stream.v1beta1.PositionsFilterB\x04\xc8\xde\x1f\x01R\x0fpositionsFilter\x12\x61\n\x13oracle_price_filter\x18\n \x01(\x0b\x32+.injective.stream.v1beta1.OraclePriceFilterB\x04\xc8\xde\x1f\x01R\x11oraclePriceFilter\"\xa1\x07\n\x0eStreamResponse\x12!\n\x0c\x62lock_height\x18\x01 \x01(\x04R\x0b\x62lockHeight\x12\x1d\n\nblock_time\x18\x02 \x01(\x03R\tblockTime\x12J\n\rbank_balances\x18\x03 \x03(\x0b\x32%.injective.stream.v1beta1.BankBalanceR\x0c\x62\x61nkBalances\x12]\n\x13subaccount_deposits\x18\x04 \x03(\x0b\x32,.injective.stream.v1beta1.SubaccountDepositsR\x12subaccountDeposits\x12\x44\n\x0bspot_trades\x18\x05 \x03(\x0b\x32#.injective.stream.v1beta1.SpotTradeR\nspotTrades\x12V\n\x11\x64\x65rivative_trades\x18\x06 \x03(\x0b\x32).injective.stream.v1beta1.DerivativeTradeR\x10\x64\x65rivativeTrades\x12J\n\x0bspot_orders\x18\x07 \x03(\x0b\x32).injective.stream.v1beta1.SpotOrderUpdateR\nspotOrders\x12\\\n\x11\x64\x65rivative_orders\x18\x08 \x03(\x0b\x32/.injective.stream.v1beta1.DerivativeOrderUpdateR\x10\x64\x65rivativeOrders\x12_\n\x16spot_orderbook_updates\x18\t \x03(\x0b\x32).injective.stream.v1beta1.OrderbookUpdateR\x14spotOrderbookUpdates\x12k\n\x1c\x64\x65rivative_orderbook_updates\x18\n \x03(\x0b\x32).injective.stream.v1beta1.OrderbookUpdateR\x1a\x64\x65rivativeOrderbookUpdates\x12@\n\tpositions\x18\x0b \x03(\x0b\x32\".injective.stream.v1beta1.PositionR\tpositions\x12J\n\roracle_prices\x18\x0c \x03(\x0b\x32%.injective.stream.v1beta1.OraclePriceR\x0coraclePrices\"f\n\x0fOrderbookUpdate\x12\x10\n\x03seq\x18\x01 \x01(\x04R\x03seq\x12\x41\n\torderbook\x18\x02 \x01(\x0b\x32#.injective.stream.v1beta1.OrderbookR\torderbook\"\xae\x01\n\tOrderbook\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12@\n\nbuy_levels\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\tbuyLevels\x12\x42\n\x0bsell_levels\x18\x03 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\nsellLevels\"\x90\x01\n\x0b\x42\x61nkBalance\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12g\n\x08\x62\x61lances\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x08\x62\x61lances\"\x88\x01\n\x12SubaccountDeposits\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12M\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32+.injective.stream.v1beta1.SubaccountDepositB\x04\xc8\xde\x1f\x00R\x08\x64\x65posits\"n\n\x11SubaccountDeposit\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x43\n\x07\x64\x65posit\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.DepositB\x04\xc8\xde\x1f\x00R\x07\x64\x65posit\"\xc2\x01\n\x0fSpotOrderUpdate\x12\x43\n\x06status\x18\x01 \x01(\x0e\x32+.injective.stream.v1beta1.OrderUpdateStatusR\x06status\x12\x1d\n\norder_hash\x18\x02 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x03 \x01(\tR\x03\x63id\x12\x39\n\x05order\x18\x04 \x01(\x0b\x32#.injective.stream.v1beta1.SpotOrderR\x05order\"p\n\tSpotOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x46\n\x05order\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderB\x04\xc8\xde\x1f\x00R\x05order\"\xce\x01\n\x15\x44\x65rivativeOrderUpdate\x12\x43\n\x06status\x18\x01 \x01(\x0e\x32+.injective.stream.v1beta1.OrderUpdateStatusR\x06status\x12\x1d\n\norder_hash\x18\x02 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x03 \x01(\tR\x03\x63id\x12?\n\x05order\x18\x04 \x01(\x0b\x32).injective.stream.v1beta1.DerivativeOrderR\x05order\"\x99\x01\n\x0f\x44\x65rivativeOrder\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12L\n\x05order\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x00R\x05order\x12\x1b\n\tis_market\x18\x03 \x01(\x08R\x08isMarket\"\x87\x03\n\x08Position\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x16\n\x06isLong\x18\x03 \x01(\x08R\x06isLong\x12?\n\x08quantity\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x44\n\x0b\x65ntry_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nentryPrice\x12;\n\x06margin\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06margin\x12]\n\x18\x63umulative_funding_entry\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16\x63umulativeFundingEntry\"t\n\x0bOraclePrice\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\"\xc3\x03\n\tSpotTrade\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x15\n\x06is_buy\x18\x02 \x01(\x08R\x05isBuy\x12$\n\rexecutionType\x18\x03 \x01(\tR\rexecutionType\x12?\n\x08quantity\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x39\n\x05price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12#\n\rsubaccount_id\x18\x06 \x01(\tR\x0csubaccountId\x12\x35\n\x03\x66\x65\x65\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x03\x66\x65\x65\x12\x1d\n\norder_hash\x18\x08 \x01(\tR\torderHash\x12\x38\n\x15\x66\x65\x65_recipient_address\x18\t \x01(\tB\x04\xc8\xde\x1f\x01R\x13\x66\x65\x65RecipientAddress\x12\x10\n\x03\x63id\x18\n \x01(\tR\x03\x63id\x12\x19\n\x08trade_id\x18\x0b \x01(\tR\x07tradeId\"\xdc\x03\n\x0f\x44\x65rivativeTrade\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x15\n\x06is_buy\x18\x02 \x01(\x08R\x05isBuy\x12$\n\rexecutionType\x18\x03 \x01(\tR\rexecutionType\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\x12P\n\x0eposition_delta\x18\x05 \x01(\x0b\x32).injective.exchange.v1beta1.PositionDeltaR\rpositionDelta\x12;\n\x06payout\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06payout\x12\x35\n\x03\x66\x65\x65\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x03\x66\x65\x65\x12\x1d\n\norder_hash\x18\x08 \x01(\tR\torderHash\x12\x38\n\x15\x66\x65\x65_recipient_address\x18\t \x01(\tB\x04\xc8\xde\x1f\x01R\x13\x66\x65\x65RecipientAddress\x12\x10\n\x03\x63id\x18\n \x01(\tR\x03\x63id\x12\x19\n\x08trade_id\x18\x0b \x01(\tR\x07tradeId\"T\n\x0cTradesFilter\x12%\n\x0esubaccount_ids\x18\x01 \x03(\tR\rsubaccountIds\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"W\n\x0fPositionsFilter\x12%\n\x0esubaccount_ids\x18\x01 \x03(\tR\rsubaccountIds\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"T\n\x0cOrdersFilter\x12%\n\x0esubaccount_ids\x18\x01 \x03(\tR\rsubaccountIds\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"0\n\x0fOrderbookFilter\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"0\n\x12\x42\x61nkBalancesFilter\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\"A\n\x18SubaccountDepositsFilter\x12%\n\x0esubaccount_ids\x18\x01 \x03(\tR\rsubaccountIds\"+\n\x11OraclePriceFilter\x12\x16\n\x06symbol\x18\x01 \x03(\tR\x06symbol*L\n\x11OrderUpdateStatus\x12\x0f\n\x0bUnspecified\x10\x00\x12\n\n\x06\x42ooked\x10\x01\x12\x0b\n\x07Matched\x10\x02\x12\r\n\tCancelled\x10\x03\x32g\n\x06Stream\x12]\n\x06Stream\x12\'.injective.stream.v1beta1.StreamRequest\x1a(.injective.stream.v1beta1.StreamResponse0\x01\x42\xf2\x01\n\x1c\x63om.injective.stream.v1beta1B\nQueryProtoP\x01ZDgithub.com/InjectiveLabs/injective-core/injective-chain/stream/types\xa2\x02\x03ISX\xaa\x02\x18Injective.Stream.V1beta1\xca\x02\x18Injective\\Stream\\V1beta1\xe2\x02$Injective\\Stream\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Stream::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.stream.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.stream.v1beta1B\nQueryProtoP\001ZDgithub.com/InjectiveLabs/injective-core/injective-chain/stream/types\242\002\003ISX\252\002\030Injective.Stream.V1beta1\312\002\030Injective\\Stream\\V1beta1\342\002$Injective\\Stream\\V1beta1\\GPBMetadata\352\002\032Injective::Stream::V1beta1'
  _globals['_STREAMREQUEST'].fields_by_name['bank_balances_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['bank_balances_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['subaccount_deposits_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['subaccount_deposits_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['spot_trades_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['spot_trades_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['derivative_trades_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['derivative_trades_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['spot_orders_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['spot_orders_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['derivative_orders_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['derivative_orders_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['spot_orderbooks_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['spot_orderbooks_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['derivative_orderbooks_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['derivative_orderbooks_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['positions_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['positions_filter']._serialized_options = b'\310\336\037\001'
  _globals['_STREAMREQUEST'].fields_by_name['oracle_price_filter']._loaded_options = None
  _globals['_STREAMREQUEST'].fields_by_name['oracle_price_filter']._serialized_options = b'\310\336\037\001'
  _globals['_BANKBALANCE'].fields_by_name['balances']._loaded_options = None
  _globals['_BANKBALANCE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_SUBACCOUNTDEPOSITS'].fields_by_name['deposits']._loaded_options = None
  _globals['_SUBACCOUNTDEPOSITS'].fields_by_name['deposits']._serialized_options = b'\310\336\037\000'
  _globals['_SUBACCOUNTDEPOSIT'].fields_by_name['deposit']._loaded_options = None
  _globals['_SUBACCOUNTDEPOSIT'].fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _globals['_SPOTORDER'].fields_by_name['order']._loaded_options = None
  _globals['_SPOTORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_DERIVATIVEORDER'].fields_by_name['order']._loaded_options = None
  _globals['_DERIVATIVEORDER'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_POSITION'].fields_by_name['quantity']._loaded_options = None
  _globals['_POSITION'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_POSITION'].fields_by_name['entry_price']._loaded_options = None
  _globals['_POSITION'].fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_POSITION'].fields_by_name['margin']._loaded_options = None
  _globals['_POSITION'].fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_POSITION'].fields_by_name['cumulative_funding_entry']._loaded_options = None
  _globals['_POSITION'].fields_by_name['cumulative_funding_entry']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_ORACLEPRICE'].fields_by_name['price']._loaded_options = None
  _globals['_ORACLEPRICE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTTRADE'].fields_by_name['quantity']._loaded_options = None
  _globals['_SPOTTRADE'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTTRADE'].fields_by_name['price']._loaded_options = None
  _globals['_SPOTTRADE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTTRADE'].fields_by_name['fee']._loaded_options = None
  _globals['_SPOTTRADE'].fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTTRADE'].fields_by_name['fee_recipient_address']._loaded_options = None
  _globals['_SPOTTRADE'].fields_by_name['fee_recipient_address']._serialized_options = b'\310\336\037\001'
  _globals['_DERIVATIVETRADE'].fields_by_name['payout']._loaded_options = None
  _globals['_DERIVATIVETRADE'].fields_by_name['payout']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVETRADE'].fields_by_name['fee']._loaded_options = None
  _globals['_DERIVATIVETRADE'].fields_by_name['fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_DERIVATIVETRADE'].fields_by_name['fee_recipient_address']._loaded_options = None
  _globals['_DERIVATIVETRADE'].fields_by_name['fee_recipient_address']._serialized_options = b'\310\336\037\001'
  _globals['_ORDERUPDATESTATUS']._serialized_start=5450
  _globals['_ORDERUPDATESTATUS']._serialized_end=5526
  _globals['_STREAMREQUEST']._serialized_start=205
  _globals['_STREAMREQUEST']._serialized_end=1243
  _globals['_STREAMRESPONSE']._serialized_start=1246
  _globals['_STREAMRESPONSE']._serialized_end=2175
  _globals['_ORDERBOOKUPDATE']._serialized_start=2177
  _globals['_ORDERBOOKUPDATE']._serialized_end=2279
  _globals['_ORDERBOOK']._serialized_start=2282
  _globals['_ORDERBOOK']._serialized_end=2456
  _globals['_BANKBALANCE']._serialized_start=2459
  _globals['_BANKBALANCE']._serialized_end=2603
  _globals['_SUBACCOUNTDEPOSITS']._serialized_start=2606
  _globals['_SUBACCOUNTDEPOSITS']._serialized_end=2742
  _globals['_SUBACCOUNTDEPOSIT']._serialized_start=2744
  _globals['_SUBACCOUNTDEPOSIT']._serialized_end=2854
  _globals['_SPOTORDERUPDATE']._serialized_start=2857
  _globals['_SPOTORDERUPDATE']._serialized_end=3051
  _globals['_SPOTORDER']._serialized_start=3053
  _globals['_SPOTORDER']._serialized_end=3165
  _globals['_DERIVATIVEORDERUPDATE']._serialized_start=3168
  _globals['_DERIVATIVEORDERUPDATE']._serialized_end=3374
  _globals['_DERIVATIVEORDER']._serialized_start=3377
  _globals['_DERIVATIVEORDER']._serialized_end=3530
  _globals['_POSITION']._serialized_start=3533
  _globals['_POSITION']._serialized_end=3924
  _globals['_ORACLEPRICE']._serialized_start=3926
  _globals['_ORACLEPRICE']._serialized_end=4042
  _globals['_SPOTTRADE']._serialized_start=4045
  _globals['_SPOTTRADE']._serialized_end=4496
  _globals['_DERIVATIVETRADE']._serialized_start=4499
  _globals['_DERIVATIVETRADE']._serialized_end=4975
  _globals['_TRADESFILTER']._serialized_start=4977
  _globals['_TRADESFILTER']._serialized_end=5061
  _globals['_POSITIONSFILTER']._serialized_start=5063
  _globals['_POSITIONSFILTER']._serialized_end=5150
  _globals['_ORDERSFILTER']._serialized_start=5152
  _globals['_ORDERSFILTER']._serialized_end=5236
  _globals['_ORDERBOOKFILTER']._serialized_start=5238
  _globals['_ORDERBOOKFILTER']._serialized_end=5286
  _globals['_BANKBALANCESFILTER']._serialized_start=5288
  _globals['_BANKBALANCESFILTER']._serialized_end=5336
  _globals['_SUBACCOUNTDEPOSITSFILTER']._serialized_start=5338
  _globals['_SUBACCOUNTDEPOSITSFILTER']._serialized_end=5403
  _globals['_ORACLEPRICEFILTER']._serialized_start=5405
  _globals['_ORACLEPRICEFILTER']._serialized_end=5448
  _globals['_STREAM']._serialized_start=5528
  _globals['_STREAM']._serialized_end=5631
# @@protoc_insertion_point(module_scope)
